"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts = require("typescript");
const chalk = require("chalk");
/**
 * Compile and return result TypeScript
 * @param filePath Path to file to compile
 */
function compile(filePath, factoryFactories) {
    const compilerOptions = {
        target: ts.ScriptTarget.ES2017,
        module: ts.ModuleKind.ES2015,
    };
    const program = ts.createProgram([filePath], compilerOptions);
    const sourceFiles = program.getSourceFiles().filter(sf => !sf.isDeclarationFile);
    const typeChecker = program.getTypeChecker();
    const result = ts.transform(sourceFiles, factoryFactories.map(factoryFactory => factoryFactory(typeChecker), compilerOptions));
    if (result.diagnostics && result.diagnostics.length) {
        console.log(chalk.yellow(`
        ======================= Diagnostics for ${filePath} =======================
        `));
        for (const diag of result.diagnostics) {
            const pos = diag.file.getLineAndCharacterOfPosition(diag.start);
            console.log(`(${pos.line}, ${pos.character}) ${diag.messageText}`);
        }
    }
    const printer = ts.createPrinter();
    // TODO: fix the index 0 access... What if program have multiple source files?
    return printer.printNode(ts.EmitHint.SourceFile, result.transformed[0], sourceFiles[0]);
}
exports.compile = compile;
//# sourceMappingURL=compiler.js.map