"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts = require("typescript");
const helpers = require("../helpers");
/**
 * Collapse unnecessary intersections between type literals
 *
 * @example
 * Before:
 * type Foo = {foo: string;} & {bar: number;}
 *
 * After
 * type Foo = {foo: string; bar: number;}
 */
function collapseIntersectionInterfacesTransformFactoryFactory(typeChecker) {
    return function collapseIntersectionInterfacesTransformFactory(context) {
        return function collapseIntersectionInterfacesTransform(sourceFile) {
            const visited = ts.visitEachChild(sourceFile, visitor, context);
            ts.addEmitHelpers(visited, context.readEmitHelpers());
            return visited;
            function visitor(node) {
                if (helpers.isTypeAliasDeclaration(node)) {
                    return visitTypeAliasDeclaration(node);
                }
                return node;
            }
            function visitTypeAliasDeclaration(node) {
                if (helpers.isIntersectionTypeNode(node.type)
                    && node.type.types.every((type) => helpers.isTypeLiteralNode(type))) {
                    const allMembers = node.type.types
                        .map((type) => type.members)
                        .reduce((all, members) => ts.createNodeArray(all.concat(members)), ts.createNodeArray([]));
                    return helpers.createTypeDeclarationStatement(node.name.text, ts.createTypeLiteralNode(allMembers), sourceFile);
                }
                return node;
            }
        };
    };
}
exports.collapseIntersectionInterfacesTransformFactoryFactory = collapseIntersectionInterfacesTransformFactoryFactory;
//# sourceMappingURL=collapse-intersection-interfaces-transform.js.map