"use strict";
/**
 * @file
 * Test runner
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs");
const src_1 = require("../src");
/** Map between a transform and its test folder */
const transformToFolderMap = [
    ['react-js-make-props-and-state-transform', [src_1.reactJSMakePropsAndStateInterfaceTransformFactoryFactory]],
    ['react-hoist-generics-transform', [src_1.reactHoistGenericsTransformFactoryFactory]],
    ['react-remove-static-prop-types-member-transform', [src_1.reactRemoveStaticPropTypesMemberTransformFactoryFactory]],
    ['react-remove-prop-types-assignment-transform', [src_1.reactRemovePropTypesAssignmentTransformFactoryFactory]],
    ['collapse-intersection-interfaces-transform', [src_1.collapseIntersectionInterfacesTransformFactoryFactory]],
    ['react-move-prop-types-to-class-transform', [src_1.reactMovePropTypesToClassTransformFactoryFactory]],
    ['end-to-end', src_1.allTransforms],
];
for (const [testFolderName, getFactory] of transformToFolderMap) {
    describe(testFolderName.replace(/\-/g, ' ').replace('transform', ''), () => {
        for (const folderName of fs.readdirSync(path.join(__dirname, testFolderName))) {
            const folder = path.join(path.join(__dirname, testFolderName, folderName));
            if (fs.statSync(folder).isDirectory()) {
                it(`${testFolderName} ${folderName}`, () => __awaiter(this, void 0, void 0, function* () {
                    const inputPath = path.join(folder, 'input.tsx');
                    const output = yield readFile(path.join(folder, 'output.tsx'));
                    const result = src_1.compile(inputPath, getFactory);
                    expect(stripEmptyLines(result)).toEqual(stripEmptyLines(output));
                }));
            }
        }
    });
}
/**
 * Remove extra empty lines
 * @param s A file text
 */
function stripEmptyLines(s) {
    const newLineRegex = /\n|\r\n/;
    return s.split(newLineRegex).filter((l) => l.trim()).join('\n');
}
/**
 * Read a string file
 * @param pathToFile Path to a string file
 */
function readFile(pathToFile) {
    return new Promise((resolve, reject) => {
        fs.readFile(pathToFile, (error, buffer) => {
            if (error) {
                return reject(error);
            }
            resolve(buffer.toString());
        });
    });
}
//# sourceMappingURL=runner.js.map